# twinLab Client

![digiLab](./resources/badges/digilab.svg)
[![slack](https://img.shields.io/badge/slack-@digilabglobal-purple.svg?logo=slack)](https://digilabglobal.slack.com)

## Documentation

See the [documentation](https://digilab-ai.github.io/twinLab/) for installation and usage instructions for MacOS, Windows and Colab.

## Having Problems?

If you have any questions or concerns you can email us at [twinlab@digilab.co.uk](twinlab@digilab.co.uk) or find out more at [digilab.co.uk/products/twinlab](https://www.digilab.co.uk/products/twinlab).